<!DOCTYPE html>
<html>

<head>
</head>

<style>
</style>

<body style="margin:0; padding:10px 0 0 0;" bgcolor="">
  <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%%">
  <div >
      <tr class=''>
        <td align="center" >
          <table class='box' align="center" border="1" cellpadding="0" cellspacing="0" width="500"
            style="border-collapse: separate; border-spacing: 1px 1px; box-shadow: 2px 2 2px 5px #88B8B6;">
            <tr>
              <td bgcolor="#ffffff" style="padding: 40px 30px 40px 30px;">
                <table border="0" cellpadding="0" cellspacing="0" width="100%%">
                  <tr>
                    <td style=" font-family: Avenir, sans-serif; font-size: 16px;" align=left>
                      <!-- Initial text goes here-->
                      {message:} 
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
            </tr>    
  </div>

  </table>

</body>

</html>

