# Generated by Django 3.2.3 on 2022-06-13 15:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_notifications', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='emailconfiguration',
            old_name='Logs_Type',
            new_name='Content_Type',
        ),
    ]
